==> haskell-chunked-data-0.3.1-352.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-chunked-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 chunked-data
version:              0.3.1
visibility:           public
id:                   chunked-data-0.3.1-1XpA4OqQLkb10YW9TdjAxS
key:                  chunked-data-0.3.1-1XpA4OqQLkb10YW9TdjAxS
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Typeclasses for dealing with various chunked data representations

description:
    See docs and README at <http://www.stackage.org/package/chunked-data>

category:             Data
abi:                  c63a60eb356aa998b621fc9bd43d9478
exposed:              True
exposed-modules:      Data.Builder Data.ChunkedZip Data.IOData
hidden-modules:       Paths_chunked_data
import-dirs:          /usr/lib/ghc-9.6.6/site-local/chunked-data-0.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/chunked-data-0.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/chunked-data-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-chunked-data
hs-libraries:         HSchunked-data-0.3.1-1XpA4OqQLkb10YW9TdjAxS
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7 text-2.0.2
    transformers-0.6.1.0 vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:
    /usr/share/doc/haskell-chunked-data/html/chunked-data.haddock

haddock-html:         /usr/share/doc/haskell-chunked-data/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-chunked-data-0.3.1-353-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-chunked-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 chunked-data
version:              0.3.1
visibility:           public
id:                   chunked-data-0.3.1-I7GmYFhCPhd3PONlJkBfdi
key:                  chunked-data-0.3.1-I7GmYFhCPhd3PONlJkBfdi
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Typeclasses for dealing with various chunked data representations

description:
    See docs and README at <http://www.stackage.org/package/chunked-data>

category:             Data
abi:                  9b89edd1823f8287c896485be3fdbf35
exposed:              True
exposed-modules:      Data.Builder Data.ChunkedZip Data.IOData
hidden-modules:       Paths_chunked_data
import-dirs:          /usr/lib/ghc-9.6.6/site-local/chunked-data-0.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/chunked-data-0.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/chunked-data-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-chunked-data
hs-libraries:         HSchunked-data-0.3.1-I7GmYFhCPhd3PONlJkBfdi
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7 text-2.0.2
    transformers-0.6.1.0 vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:
    /usr/share/doc/haskell-chunked-data/html/chunked-data.haddock

haddock-html:         /usr/share/doc/haskell-chunked-data/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
